@@ -44,10 +44,14 @@ class logger:
 
         if level == 'info':
             self.logger.info(message)
-        elif level == 'debug':
-            self.logger.debug(message)
         elif level == 'error':
             self.logger.error(message)
+        elif level == 'debug':
+            self.logger.debug(message)
+        elif level == 'success':
+            self.logger.success(message)
+        elif level == 'warning':
+            self.logger.warning(message)
 
         if not message:
             log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
@@ -63,6 +67,12 @@ class logger:
     def debug(self, *items):
         self.log(*items, level='debug')
     
+    def success(self, *items):
+        self.log(*items, level='success')
+    
+    def warning(self, *items):
+        self.log(*items, level='warning')
+    
     def current_time(self, *items, level='info'):
         coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(asctime)s.%(msecs)03d: %(message)s', datefmt='%H:%M:%S') # Add curent time to printed log output format
         self.log(*items, level=level)
